Struct AddressBookConfig
pub struct AddressBookConfig<Z>where
Z: NetworkZone,{
pub max_white_list_length: usize,
pub max_gray_list_length: usize,
pub peer_store_directory: PathBuf,
pub peer_save_period: Duration,
pub our_own_address: Option<<Z as NetworkZone>::Addr>,
}Expand description
The address book config.
Fields
max_white_list_length: usizeThe maximum number of white peers in the peer list.
White peers are peers we have connected to before.
max_gray_list_length: usizeThe maximum number of gray peers in the peer list.
Gray peers are peers we are yet to make a connection to.
peer_store_directory: PathBufThe location to store the peer store files.
peer_save_period: DurationThe amount of time between saving the address book to disk.
our_own_address: Option<<Z as NetworkZone>::Addr>Our own address to advertise to peers. (Only set if Z::BROADCAST_OWN_ADDR = true)