P2PConfig

Struct P2PConfig 

pub struct P2PConfig<Z: NetworkZone> {
    pub network: Network,
    pub seeds: Vec<Z::Addr>,
    pub offline: bool,
    pub outbound_connections: usize,
    pub extra_outbound_connections: usize,
    pub max_inbound_connections: usize,
    pub gray_peers_percent: f64,
    pub p2p_port: u16,
    pub rpc_port: u16,
    pub address_book_config: AddressBookConfig<Z>,
}
P2P config.

Fields

network: Network

The Network we should connect to.

seeds: Vec<Z::Addr>

Seed nodes to connect to find peers if our address book is empty.

offline: bool

Whether to run in offline mode.

outbound_connections: usize

The number of outbound connections to make and try keep.

extra_outbound_connections: usize

The amount of extra connections we can make if we are under load from the rest of Cuprate.

max_inbound_connections: usize

The maximum amount of inbound connections.

gray_peers_percent: f64

The percent of outbound peers that should be gray aka never connected to before.

Only values 0..=1 are valid.

p2p_port: u16

The port to listen on for inbound connections.

rpc_port: u16

The public RPC port to tell peers about so wallets can use our node. 0 if we do not have a public RPC port.

address_book_config: AddressBookConfig<Z>