pub struct P2PConfig<Z: NetworkZone> {
pub network: Network,
pub seeds: Vec<Z::Addr>,
pub offline: bool,
pub outbound_connections: usize,
pub extra_outbound_connections: usize,
pub max_inbound_connections: usize,
pub gray_peers_percent: f64,
pub p2p_port: u16,
pub rpc_port: u16,
pub address_book_config: AddressBookConfig<Z>,
}Expand description
P2P config.
Fields
network: NetworkThe Network we should connect to.
seeds: Vec<Z::Addr>Seed nodes to connect to find peers if our address book is empty.
offline: boolWhether to run in offline mode.
outbound_connections: usizeThe number of outbound connections to make and try keep.
extra_outbound_connections: usizeThe amount of extra connections we can make if we are under load from the rest of Cuprate.
max_inbound_connections: usizeThe maximum amount of inbound connections.
gray_peers_percent: f64The percent of outbound peers that should be gray aka never connected to before.
Only values 0..=1 are valid.
p2p_port: u16The port to listen on for inbound connections.
rpc_port: u16The public RPC port to tell peers about so wallets can use our node. 0 if we do not have a public RPC port.
address_book_config: AddressBookConfig<Z>The AddressBookConfig.